@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import MessageEvent
 from arrow_bpmn.model.event.endevent.none_end_event import NoneEndEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class MessageEndEvent(NoneEndEvent):
@@ -14,7 +13,7 @@ class MessageEndEvent(NoneEndEvent):
     When process execution arrives at a Message End Event, the current path of execution is ended and a message is sent.
     """
 
-    def __init__(self, element: XMLElement, message: str):
+    def __init__(self, element: dict, message: str):
         super().__init__(element)
         self.message = message
 
