@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import SignalEvent
 from arrow_bpmn.model.event.endevent.none_end_event import NoneEndEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class SignalEndEvent(NoneEndEvent):
@@ -14,7 +13,7 @@ class SignalEndEvent(NoneEndEvent):
     When process execution arrives at a Signal End Event, the current path of execution is ended and a signal is sent.
     """
 
-    def __init__(self, element: XMLElement, signal: str):
+    def __init__(self, element: dict, signal: str):
         super().__init__(element)
         self.signal = signal
 
