@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.action.event_action import EventAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import MessageEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class MessageIntermediateThrowEvent(BpmnNode):
@@ -14,7 +13,7 @@ class MessageIntermediateThrowEvent(BpmnNode):
     A Message Intermediate Throwing event sends a message to an external service.
     """
 
-    def __init__(self, element: XMLElement, message: str):
+    def __init__(self, element: dict, message: str):
         super().__init__(element)
         self.message = message
 
