@@ -5,7 +5,6 @@ from arrow_bpmn.__spi__.action import Actions, ContinueAction, QueueAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import SignalEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class SignalIntermediateCatchEvent(BpmnNode):
@@ -14,7 +13,7 @@ class SignalIntermediateCatchEvent(BpmnNode):
     name arrives.
     """
 
-    def __init__(self, element: XMLElement, signal: str):
+    def __init__(self, element: dict, signal: str):
         super().__init__(element)
         self.signal = signal
 
@@ -23,7 +22,7 @@ class SignalIntermediateCatchEvent(BpmnNode):
             actions = [ContinueAction(node) for node in environment.get_outgoing_nodes(self.id)]
             return state, [CompleteAction(self.id)] + actions
 
-        return state, [QueueAction(self.id, event=SignalEvent(environment.group, self.signal))]
+        return state, [QueueAction(self.id, event=SignalEvent(environment.group, self.signal), save_state=True)]
 
     def __repr__(self):
         return f"SignalIntermediateCatchEvent({self.id})"
