@@ -39,7 +39,7 @@ class ExclusiveGateway(BpmnNode):
         # ************************************
         for edge in environment.get_outgoing_edges(self.id):
             if edge.expression is not None:
-                engine = environment.script_factory(state, "hypothesis", edge.expression)
+                engine = environment.script_factory(state, "typescript", edge.expression)
                 if engine(state.properties):
                     return state, [CompleteAction(self.id), ContinueAction(edge.target_ref)]
 
