@@ -77,7 +77,7 @@ class HttpTask(BpmnNode):
             """
             accept = headers["ACCEPT"] if "ACCEPT" in headers else "application/json"
 
-            if response.status_code < 300:
+            if response.status_code > 300:
                 raise ValueError(response.text)
 
             if self.response_expression is None:
