@@ -13,14 +13,10 @@ class SendTask(BpmnNode):
     A Send Task is used to send a message.
     """
 
-    def __init__(self, element: dict):
-        super().__init__(element)
-
     @property
     def message_ref(self):
         return self.__dict__["messageRef"]
 
-    # noinspection PyBroadException
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         event = MessageEvent(self.id, environment.get_message(self.message_ref))
 
