@@ -13,5 +13,5 @@ class JSONElement:
     def __getitem__(self, item):
         return self.item[item]
 
-    def as_dict(self) -> dict:
-        return self.item
\ No newline at end of file
+    def as_dict(self):
+        return self.item
